@@ -19,26 +19,25 @@ class MemcachedDriver(drivers.Driver):
     DEFAULT_PORT = 11212
 
     def __init__(self, port=DEFAULT_PORT, **kwargs):
+        """Create a new memcached server."""
         super(MemcachedDriver, self).__init__(**kwargs)
         self.port = port
 
     @classmethod
-    def get_parser(cls, parser):
-        parser.add_argument("--port",
-                            type=int,
-                            default=cls.DEFAULT_PORT,
-                            help="port to use for memcached")
-        return parser
+    def get_options(cls):
+        return [
+            {"param_decls": ["--port"],
+             "type": int,
+             "default": cls.DEFAULT_PORT,
+             "help": "port to use for memcached"},
+        ]
 
     def _setUp(self):
         super(MemcachedDriver, self)._setUp()
 
         c, _ = self._exec(["memcached",
-                           "-vv",
                            "-p " + str(self.port)],
-                          wait_for_line="server listening")
-
-        self.addCleanup(self._kill, c)
+                          wait_for_port=self.port)
 
         self.putenv("MEMCACHED_PORT", str(self.port))
         self.putenv("URL", "memcached://localhost:%d" % self.port)
